==> asset-manager-api-5.0-sources.jar: org/odpi/openmetadata/accessservices/assetmanager/rest/AssetManagerOMASAPIResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.assetmanager.rest;

import com.fasterxml.jackson.annotation.*;
import org.odpi.openmetadata.commonservices.ffdc.rest.FFDCResponseBase;

import java.util.Arrays;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * AssetManagerOMASAPIResponse provides a common header for Asset Manager OMAS managed rest to its REST API.
 * It manages information about exceptions.  If no exception has been raised exceptionClassName is null.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME,
        include = JsonTypeInfo.As.PROPERTY,
        property = "class")
@JsonSubTypes(
        {
                @JsonSubTypes.Type(value = GlossaryElementResponse.class, name = "GlossaryElementResponse"),
                @JsonSubTypes.Type(value = GlossaryElementsResponse.class, name = "GlossaryElementsResponse"),
                @JsonSubTypes.Type(value = GlossaryCategoryElementResponse.class, name = "GlossaryCategoryElementResponse"),
                @JsonSubTypes.Type(value = GlossaryCategoryElementsResponse.class, name = "GlossaryCategoryElementsResponse"),
                @JsonSubTypes.Type(value = GlossaryTermElementResponse.class, name = "GlossaryTermElementResponse"),
                @JsonSubTypes.Type(value = GlossaryTermElementsResponse.class, name = "GlossaryTermElementsResponse"),
        })
public abstract class AssetManagerOMASAPIResponse extends FFDCResponseBase
{
    /**
     * Default constructor
     */
    public AssetManagerOMASAPIResponse()
    {
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public AssetManagerOMASAPIResponse(AssetManagerOMASAPIResponse template)
    {
        super(template);
    }


    /**
     * JSON-like toString
     *
     * @return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "AssetManagerOMASAPIResponse{" +
                "exceptionClassName='" + getExceptionClassName() + '\'' +
                ", exceptionCausedBy='" + getExceptionCausedBy() + '\'' +
                ", actionDescription='" + getActionDescription() + '\'' +
                ", relatedHTTPCode=" + getRelatedHTTPCode() +
                ", exceptionErrorMessage='" + getExceptionErrorMessage() + '\'' +
                ", exceptionErrorMessageId='" + getExceptionErrorMessageId() + '\'' +
                ", exceptionErrorMessageParameters=" + Arrays.toString(getExceptionErrorMessageParameters()) +
                ", exceptionSystemAction='" + getExceptionSystemAction() + '\'' +
                ", exceptionUserAction='" + getExceptionUserAction() + '\'' +
                ", exceptionProperties=" + getExceptionProperties() +
                '}';
    }
}

==> asset-manager-api-5.3-sources.jar: org/odpi/openmetadata/accessservices/assetmanager/rest/AssetManagerOMASAPIResponse.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.assetmanager.rest;

import com.fasterxml.jackson.annotation.*;
import org.odpi.openmetadata.commonservices.ffdc.rest.FFDCResponseBase;

import java.util.Arrays;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * AssetManagerOMASAPIResponse provides a common header for Asset Manager OMAS managed rest to its REST API.
 * It manages information about exceptions.  If no exception has been raised exceptionClassName is null.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME,
        include = JsonTypeInfo.As.PROPERTY,
        property = "class")
@JsonSubTypes(
        {
                @JsonSubTypes.Type(value = GlossaryElementResponse.class, name = "GlossaryElementResponse"),
                @JsonSubTypes.Type(value = GlossaryElementsResponse.class, name = "GlossaryElementsResponse"),
                @JsonSubTypes.Type(value = GlossaryCategoryElementResponse.class, name = "GlossaryCategoryElementResponse"),
                @JsonSubTypes.Type(value = GlossaryCategoryElementsResponse.class, name = "GlossaryCategoryElementsResponse"),
                @JsonSubTypes.Type(value = GlossaryTermElementResponse.class, name = "GlossaryTermElementResponse"),
                @JsonSubTypes.Type(value = GlossaryTermElementsResponse.class, name = "GlossaryTermElementsResponse"),
        })
public abstract class AssetManagerOMASAPIResponse extends FFDCResponseBase
{
    /**
     * Default constructor
     */
    public AssetManagerOMASAPIResponse()
    {
    }


    /**
     * Copy/clone constructor
     *
     * @param template object to copy
     */
    public AssetManagerOMASAPIResponse(AssetManagerOMASAPIResponse template)
    {
        super(template);
    }


    /**
     * JSON-like toString
     *
     * @return string containing the property names and values
     */
    @Override
    public String toString()
    {
        return "AssetManagerOMASAPIResponse{} " + super.toString();
    }
}
